@@ -8,7 +8,7 @@ use async_http_range_reader::AsyncHttpRangeReader;
 use futures::{FutureExt, StreamExt, TryStreamExt};
 use http::HeaderMap;
 use itertools::Either;
-use reqwest::{Client, Response, StatusCode};
+use reqwest::{Proxy, Response, StatusCode};
 use reqwest_middleware::ClientWithMiddleware;
 use tokio::sync::Semaphore;
 use tracing::{info_span, instrument, trace, warn, Instrument};
@@ -115,12 +115,6 @@ impl<'a> RegistryClientBuilder<'a> {
         self
     }
 
-    #[must_use]
-    pub fn client(mut self, client: Client) -> Self {
-        self.base_client_builder = self.base_client_builder.client(client);
-        self
-    }
-
     #[must_use]
     pub fn extra_middleware(mut self, middleware: ExtraMiddleware) -> Self {
         self.base_client_builder = self.base_client_builder.extra_middleware(middleware);
@@ -139,6 +133,12 @@ impl<'a> RegistryClientBuilder<'a> {
         self
     }
 
+    #[must_use]
+    pub fn proxy(mut self, proxy: Proxy) -> Self {
+        self.base_client_builder = self.base_client_builder.proxy(proxy);
+        self
+    }
+
     pub fn build(self) -> RegistryClient {
         // Build a base client
         let builder = self.base_client_builder;
@@ -347,7 +347,7 @@ impl RegistryClient {
         let cache_control = match self.connectivity {
             Connectivity::Online => CacheControl::from(
                 self.cache
-                    .freshness(&cache_entry, Some(package_name))
+                    .freshness(&cache_entry, Some(package_name), None)
                     .map_err(ErrorKind::Io)?,
             ),
             Connectivity::Offline => CacheControl::AllowStale,
@@ -632,7 +632,7 @@ impl RegistryClient {
             let cache_control = match self.connectivity {
                 Connectivity::Online => CacheControl::from(
                     self.cache
-                        .freshness(&cache_entry, Some(&filename.name))
+                        .freshness(&cache_entry, Some(&filename.name), None)
                         .map_err(ErrorKind::Io)?,
                 ),
                 Connectivity::Offline => CacheControl::AllowStale,
@@ -702,7 +702,7 @@ impl RegistryClient {
         let cache_control = match self.connectivity {
             Connectivity::Online => CacheControl::from(
                 self.cache
-                    .freshness(&cache_entry, Some(&filename.name))
+                    .freshness(&cache_entry, Some(&filename.name), None)
                     .map_err(ErrorKind::Io)?,
             ),
             Connectivity::Offline => CacheControl::AllowStale,
