@@ -1,4 +1,5 @@
 use either::Either;
+use std::path::{Path, PathBuf};
 use uv_pep508::PackageName;
 
 use rustc_hash::FxHashMap;
@@ -18,7 +19,7 @@ pub enum Reinstall {
     All,
 
     /// Reinstall only the specified packages.
-    Packages(Vec<PackageName>),
+    Packages(Vec<PackageName>, Vec<PathBuf>),
 }
 
 impl Reinstall {
@@ -31,7 +32,7 @@ impl Reinstall {
                 if reinstall_package.is_empty() {
                     Self::None
                 } else {
-                    Self::Packages(reinstall_package)
+                    Self::Packages(reinstall_package, Vec::new())
                 }
             }
         }
@@ -48,11 +49,22 @@ impl Reinstall {
     }
 
     /// Returns `true` if the specified package should be reinstalled.
-    pub fn contains(&self, package_name: &PackageName) -> bool {
+    pub fn contains_package(&self, package_name: &PackageName) -> bool {
         match &self {
             Self::None => false,
             Self::All => true,
-            Self::Packages(packages) => packages.contains(package_name),
+            Self::Packages(packages, ..) => packages.contains(package_name),
+        }
+    }
+
+    /// Returns `true` if the specified path should be reinstalled.
+    pub fn contains_path(&self, path: &Path) -> bool {
+        match &self {
+            Self::None => false,
+            Self::All => true,
+            Self::Packages(.., paths) => paths
+                .iter()
+                .any(|target| same_file::is_same_file(path, target).unwrap_or(false)),
         }
     }
 
@@ -65,19 +77,46 @@ impl Reinstall {
             // If either is `All`, the result is `All`.
             (Self::All, _) | (_, Self::All) => Self::All,
             // If one is `None`, the result is the other.
-            (Self::Packages(a), Self::None) => Self::Packages(a),
-            (Self::None, Self::Packages(b)) => Self::Packages(b),
+            (Self::Packages(a1, a2), Self::None) => Self::Packages(a1, a2),
+            (Self::None, Self::Packages(b1, b2)) => Self::Packages(b1, b2),
             // If both are `Packages`, the result is the union of the two.
-            (Self::Packages(mut a), Self::Packages(b)) => {
-                a.extend(b);
-                Self::Packages(a)
+            (Self::Packages(mut a1, mut a2), Self::Packages(b1, b2)) => {
+                a1.extend(b1);
+                a2.extend(b2);
+                Self::Packages(a1, a2)
+            }
+        }
+    }
+
+    /// Add a [`PathBuf`] to the [`Reinstall`] policy.
+    #[must_use]
+    pub fn with_path(self, path: PathBuf) -> Self {
+        match self {
+            Self::None => Self::Packages(vec![], vec![path]),
+            Self::All => Self::All,
+            Self::Packages(packages, mut paths) => {
+                paths.push(path);
+                Self::Packages(packages, paths)
+            }
+        }
+    }
+
+    /// Add a [`Package`] to the [`Reinstall`] policy.
+    #[must_use]
+    pub fn with_package(self, package_name: PackageName) -> Self {
+        match self {
+            Self::None => Self::Packages(vec![package_name], vec![]),
+            Self::All => Self::All,
+            Self::Packages(mut packages, paths) => {
+                packages.push(package_name);
+                Self::Packages(packages, paths)
             }
         }
     }
 
     /// Create a [`Reinstall`] strategy to reinstall a single package.
     pub fn package(package_name: PackageName) -> Self {
-        Self::Packages(vec![package_name])
+        Self::Packages(vec![package_name], vec![])
     }
 }
 
@@ -87,7 +126,9 @@ impl From<Reinstall> for Refresh {
         match value {
             Reinstall::None => Self::None(Timestamp::now()),
             Reinstall::All => Self::All(Timestamp::now()),
-            Reinstall::Packages(packages) => Self::Packages(packages, Timestamp::now()),
+            Reinstall::Packages(packages, paths) => {
+                Self::Packages(packages, paths, Timestamp::now())
+            }
         }
     }
 }
@@ -200,9 +241,11 @@ impl From<Upgrade> for Refresh {
         match value {
             Upgrade::None => Self::None(Timestamp::now()),
             Upgrade::All => Self::All(Timestamp::now()),
-            Upgrade::Packages(packages) => {
-                Self::Packages(packages.into_keys().collect::<Vec<_>>(), Timestamp::now())
-            }
+            Upgrade::Packages(packages) => Self::Packages(
+                packages.into_keys().collect::<Vec<_>>(),
+                Vec::new(),
+                Timestamp::now(),
+            ),
         }
     }
 }
