@@ -4,7 +4,7 @@ use std::str::FromStr;
 use thiserror::Error;
 use url::Url;
 
-use uv_auth::Credentials;
+use uv_auth::{AuthPolicy, Credentials};
 
 use crate::index_name::{IndexName, IndexNameError};
 use crate::origin::Origin;
@@ -82,6 +82,16 @@ pub struct Index {
     /// publish-url = "https://upload.pypi.org/legacy/"
     /// ```
     pub publish_url: Option<Url>,
+    /// When uv should use authentication for requests to the index.
+    ///
+    /// ```toml
+    /// [[tool.uv.index]]
+    /// name = "my-index"
+    /// url = "https://<omitted>/simple"
+    /// authenticate = "always"
+    /// ```
+    #[serde(default)]
+    pub authenticate: AuthPolicy,
 }
 
 // #[derive(
@@ -106,6 +116,7 @@ impl Index {
             default: true,
             origin: None,
             publish_url: None,
+            authenticate: AuthPolicy::default(),
         }
     }
 
@@ -118,6 +129,7 @@ impl Index {
             default: false,
             origin: None,
             publish_url: None,
+            authenticate: AuthPolicy::default(),
         }
     }
 
@@ -130,6 +142,7 @@ impl Index {
             default: false,
             origin: None,
             publish_url: None,
+            authenticate: AuthPolicy::default(),
         }
     }
 
@@ -160,20 +173,7 @@ impl Index {
     /// For indexes with a `/simple` endpoint, this is simply the URL with the final segment
     /// removed. This is useful, e.g., for credential propagation to other endpoints on the index.
     pub fn root_url(&self) -> Option<Url> {
-        let mut segments = self.raw_url().path_segments()?;
-        let last = match segments.next_back()? {
-            // If the last segment is empty due to a trailing `/`, skip it (as in `pop_if_empty`)
-            "" => segments.next_back()?,
-            segment => segment,
-        };
-
-        if !last.eq_ignore_ascii_case("simple") {
-            return None;
-        }
-
-        let mut url = self.raw_url().clone();
-        url.path_segments_mut().ok()?.pop_if_empty().pop();
-        Some(url)
+        self.url.root()
     }
 
     /// Retrieve the credentials for the index, either from the environment, or from the URL itself.
@@ -216,6 +216,7 @@ impl FromStr for Index {
                     default: false,
                     origin: None,
                     publish_url: None,
+                    authenticate: AuthPolicy::default(),
                 });
             }
         }
@@ -229,6 +230,7 @@ impl FromStr for Index {
             default: false,
             origin: None,
             publish_url: None,
+            authenticate: AuthPolicy::default(),
         })
     }
 }
