@@ -347,6 +347,12 @@ impl EnvVars {
     /// Path to system-level configuration directory on Windows systems.
     pub const SYSTEMDRIVE: &'static str = "SYSTEMDRIVE";
 
+    /// Path to user-level configuration directory on Windows systems.
+    pub const APPDATA: &'static str = "APPDATA";
+
+    /// Path to root directory of user's profile on Windows systems.
+    pub const USERPROFILE: &'static str = "USERPROFILE";
+
     /// Path to user-level configuration directory on Unix systems.
     pub const XDG_CONFIG_HOME: &'static str = "XDG_CONFIG_HOME";
 
@@ -665,6 +671,6 @@ impl EnvVars {
 
     /// Overrides terminal width used for wrapping. This variable is not read by uv directly.
     ///
-    /// This is a quasi-standard variable, described e.g. in `ncurses(3x)`.
+    /// This is a quasi-standard variable, described, e.g., in `ncurses(3x)`.
     pub const COLUMNS: &'static str = "COLUMNS";
 }
