@@ -242,10 +242,9 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
             };
 
             // Generate a lockfile.
-            let lock = match project::lock::do_safe_lock(
+            let lock = match project::lock::LockOperation::new(
                 mode,
-                target,
-                settings.as_ref().into(),
+                &settings.resolver,
                 &network_settings,
                 &lock_state,
                 if show_resolution {
@@ -258,6 +257,7 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
                 printer,
                 preview,
             )
+            .execute(target)
             .await
             {
                 Ok(result) => result.into_lock(),
@@ -288,7 +288,7 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
                 editable,
                 install_options,
                 modifications,
-                settings.as_ref().into(),
+                (&settings).into(),
                 &network_settings,
                 &sync_state,
                 if show_resolution {
@@ -334,7 +334,7 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
             }
 
             // Install the script requirements, if necessary. Otherwise, use an isolated environment.
-            if let Some(spec) = script_specification((&script).into(), settings.as_ref().into())? {
+            if let Some(spec) = script_specification((&script).into(), &settings.resolver)? {
                 let environment = ScriptEnvironment::get_or_init(
                     (&script).into(),
                     python.as_deref().map(PythonRequest::parse),
@@ -661,10 +661,9 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
                     LockMode::Write(venv.interpreter())
                 };
 
-                let result = match project::lock::do_safe_lock(
+                let result = match project::lock::LockOperation::new(
                     mode,
-                    project.workspace().into(),
-                    settings.as_ref().into(),
+                    &settings.resolver,
                     &network_settings,
                     &lock_state,
                     if show_resolution {
@@ -677,6 +676,7 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
                     printer,
                     preview,
                 )
+                .execute(project.workspace().into())
                 .await
                 {
                     Ok(result) => result,
@@ -750,7 +750,7 @@ hint: If you are running a script with `{}` in the shebang, you may need to incl
                     editable,
                     install_options,
                     modifications,
-                    settings.as_ref().into(),
+                    (&settings).into(),
                     &network_settings,
                     &sync_state,
                     if show_resolution {
